Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(924)

Unified Diff: src/gpu/GrGpu.h

Issue 15331003: fix slowness of getImageData() for CanvasRenderingContext2D in linux due to un-optimized format for… (Closed) Base URL: https://skia.googlecode.com/svn/trunk
Patch Set: patch preferredReadPixelsConfig() Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrContext.cpp ('k') | src/gpu/gl/GrGpuGL.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrGpu.h
diff --git a/src/gpu/GrGpu.h b/src/gpu/GrGpu.h
index ade64312b866ac0f831ad9b20e413143cd6c1ba9..467462a42b4f78bfff36c866ec9844dd24b0b674 100644
--- a/src/gpu/GrGpu.h
+++ b/src/gpu/GrGpu.h
@@ -153,10 +153,10 @@ public:
/**
* Gets a preferred 8888 config to use for writing / reading pixel data. The returned config
* must have at least as many bits per channel as the config param.
*/
- virtual GrPixelConfig preferredReadPixelsConfig(GrPixelConfig config) const { return config; }
- virtual GrPixelConfig preferredWritePixelsConfig(GrPixelConfig config) const { return config; }
+ virtual GrPixelConfig preferredReadPixelsConfig(GrPixelConfig readConfig, GrPixelConfig targetConfig) const { return readConfig; }
+ virtual GrPixelConfig preferredWritePixelsConfig(GrPixelConfig writeConfig, GrPixelConfig targetConfig) const { return writeConfig; }
/**
* Called before uploading writing pixels to a GrTexture when the src pixel config doesn't
« no previous file with comments | « src/gpu/GrContext.cpp ('k') | src/gpu/gl/GrGpuGL.h » ('j') | no next file with comments »
@@ -153,10 +153,10 @@ public:
/**
* Gets a preferred 8888 config to use for writing / reading pixel data. The returned config
- * must have at least as many bits per channel as the config param.
+ * must have at least as many bits per channel as the readConfig or writeConfig param.
*/

Powered by Google App Engine
This is Rietveld 408576698